pub enum RuntimeLayoutError {
InvalidRepoSlug {
slug: String,
},
InvalidTaskId {
task_id: String,
},
}Expand description
Errors emitted by canonical runtime-layout helpers.
Variants
InvalidRepoSlug
Repo slug is empty or contains a path separator after substitution.
InvalidTaskId
Task id is empty or contains a path separator.